@@ -20,16 +20,19 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#if !defined(__CLUTTER_H_INSIDE__) && !defined(CLUTTER_COMPILATION)
+#error "Only <clutter/clutter.h> can be included directly."
+#endif
+
 #ifndef __CLUTTER_BEHAVIOUR_PATH_H__
 #define __CLUTTER_BEHAVIOUR_PATH_H__
 
 #include <clutter/clutter-alpha.h>
 #include <clutter/clutter-behaviour.h>
+#include <clutter/clutter-path.h>
 
 G_BEGIN_DECLS
 
@@ -58,7 +61,15 @@ G_BEGIN_DECLS
 typedef struct _ClutterBehaviourPath        ClutterBehaviourPath;
 typedef struct _ClutterBehaviourPathPrivate ClutterBehaviourPathPrivate;
 typedef struct _ClutterBehaviourPathClass   ClutterBehaviourPathClass;
- 
+
+/**
+ * ClutterBehaviourPath:
+ *
+ * The #ClutterBehaviourPath structure contains only private data
+ * and should be accessed using the provided API
+ *
+ * Since: 0.2
+ */
 struct _ClutterBehaviourPath
 {
   /*< private >*/
@@ -71,7 +82,9 @@ struct _ClutterBehaviourPath
  * @knot_reached: signal class handler for the
  *   ClutterBehaviourPath::knot_reached signal
  *
- * Since 0.2
+ * The #ClutterBehaviourPathClass struct contains only private data
+ *
+ * Since: 0.2
  */
 struct _ClutterBehaviourPathClass
 {
@@ -80,7 +93,7 @@ struct _ClutterBehaviourPathClass
 
   /*< public >*/
   void (*knot_reached) (ClutterBehaviourPath *pathb,
-                        const ClutterKnot    *knot);
+                        guint                 knot_num);
 
   /*< private >*/
   void (*_clutter_path_1) (void);
@@ -92,21 +105,21 @@ struct _ClutterBehaviourPathClass
 GType clutter_behaviour_path_get_type (void) G_GNUC_CONST;
 
 ClutterBehaviour *clutter_behaviour_path_new          (ClutterAlpha         *alpha,
+                                                       ClutterPath          *path);
+
+ClutterBehaviour *clutter_behaviour_path_new_with_description
+                                                      (ClutterAlpha         *alpha,
+                                                       const gchar          *desc);
+
+ClutterBehaviour *clutter_behaviour_path_new_with_knots
+                                                      (ClutterAlpha         *alpha,
                                                        const ClutterKnot    *knots,
                                                        guint                 n_knots);
-GSList *          clutter_behaviour_path_get_knots    (ClutterBehaviourPath *pathb);
-void              clutter_behaviour_path_append_knot  (ClutterBehaviourPath *pathb,
-                                                       const ClutterKnot    *knot);
-void              clutter_behaviour_path_append_knots (ClutterBehaviourPath *pathb,
-                                                       const ClutterKnot    *first_knot,
-                                                       ...) G_GNUC_NULL_TERMINATED;
-void              clutter_behaviour_path_insert_knot  (ClutterBehaviourPath  *pathb,
-				                       guint                  offset,
-				                       const ClutterKnot     *knot);
-void              clutter_behaviour_path_remove_knot  (ClutterBehaviourPath  *pathb,
-				                       guint                  offset);
 
-void              clutter_behaviour_path_clear        (ClutterBehaviourPath  *pathb);
+void              clutter_behaviour_path_set_path     (ClutterBehaviourPath *pathb,
+                                                       ClutterPath          *path);
+
+ClutterPath *     clutter_behaviour_path_get_path     (ClutterBehaviourPath *pathb);
 
 G_END_DECLS
 
