@@ -17,6 +17,9 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Author:
+ *      Emmanuele Bassi <ebassi@linux.intel.com>
  */
 
 /**
@@ -130,12 +133,31 @@ clutter_box_real_add (ClutterContainer *container,
                       ClutterActor     *actor)
 {
   ClutterBoxPrivate *priv = CLUTTER_BOX (container)->priv;
+  GList *l, *prev = NULL;
+  gfloat actor_depth;
 
   g_object_ref (actor);
 
-  priv->children = g_list_insert_sorted (priv->children,
-                                         actor,
-                                         sort_by_depth);
+  actor_depth = clutter_actor_get_depth (actor);
+
+  /* Find the right place to insert the child so that it will still be
+     sorted and the child will be after all of the actors at the same
+     depth */
+  for (l = priv->children;
+       l && (clutter_actor_get_depth (l->data) <= actor_depth);
+       l = l->next)
+    prev = l;
+
+  /* Insert the node before the found node */
+  l = g_list_prepend (l, actor);
+  /* Fixup the links */
+  if (prev)
+    {
+      prev->next = l;
+      l->prev = prev;
+    }
+  else
+    priv->children = l;
 
   clutter_actor_set_parent (actor, CLUTTER_ACTOR (container));
 
@@ -289,20 +311,6 @@ clutter_box_real_get_preferred_width (ClutterActor *actor,
 {
   ClutterBoxPrivate *priv = CLUTTER_BOX (actor)->priv;
 
-  /* if we don't have any children don't bother proxying the
-   * call to the layout manager instance
-   */
-  if (priv->children == NULL || priv->manager == NULL)
-    {
-      if (min_width)
-        *min_width = 0.0;
-
-      if (natural_width)
-        *natural_width = 0.0;
-
-      return;
-    }
-
   clutter_layout_manager_get_preferred_width (priv->manager,
                                               CLUTTER_CONTAINER (actor),
                                               for_height,
@@ -317,20 +325,6 @@ clutter_box_real_get_preferred_height (ClutterActor *actor,
 {
   ClutterBoxPrivate *priv = CLUTTER_BOX (actor)->priv;
 
-  /* if we don't have any children don't bother proxying the
-   * call to the layout manager instance
-   */
-  if (priv->children == NULL || priv->manager == NULL)
-    {
-      if (min_height)
-        *min_height = 0.0;
-
-      if (natural_height)
-        *natural_height = 0.0;
-
-      return;
-    }
-
   clutter_layout_manager_get_preferred_height (priv->manager,
                                                CLUTTER_CONTAINER (actor),
                                                for_width,
@@ -348,9 +342,6 @@ clutter_box_real_allocate (ClutterActor           *actor,
   klass = CLUTTER_ACTOR_CLASS (clutter_box_parent_class);
   klass->allocate (actor, allocation, flags);
 
-  if (priv->children == NULL || priv->manager == NULL)
-    return;
-
   clutter_layout_manager_allocate (priv->manager,
                                    CLUTTER_CONTAINER (actor),
                                    allocation, flags);
@@ -738,8 +729,15 @@ clutter_box_set_property_valist (ClutterBox   *box,
           break;
         }
 
+#if GLIB_CHECK_VERSION (2, 23, 2)
+      G_VALUE_COLLECT_INIT (&value, G_PARAM_SPEC_VALUE_TYPE (pspec),
+                            var_args, 0,
+                            &error);
+#else
       g_value_init (&value, G_PARAM_SPEC_VALUE_TYPE (pspec));
       G_VALUE_COLLECT (&value, var_args, 0, &error);
+#endif /* GLIB_CHECK_VERSION (2, 23, 2) */
+
       if (error)
         {
           g_warning ("%s: %s", G_STRLOC, error);
@@ -800,7 +798,7 @@ clutter_box_pack (ClutterBox   *box,
  * clutter_box_pack_after:
  * @box: a #ClutterBox
  * @actor: a #ClutterActor
- * @sibling: (allow none): a #ClutterActor or %NULL
+ * @sibling: (allow-none): a #ClutterActor or %NULL
  * @first_property: the name of the first property to set, or %NULL
  * @Varargs: a list of property name and value pairs, terminated by %NULL
  *
@@ -844,7 +842,7 @@ clutter_box_pack_after (ClutterBox   *box,
  * clutter_box_pack_before:
  * @box: a #ClutterBox
  * @actor: a #ClutterActor
- * @sibling: (allow none): a #ClutterActor or %NULL
+ * @sibling: (allow-none): a #ClutterActor or %NULL
  * @first_property: the name of the first property to set, or %NULL
  * @Varargs: a list of property name and value pairs, terminated by %NULL
  *
@@ -925,6 +923,11 @@ clutter_box_pack_at (ClutterBox   *box,
   clutter_actor_set_parent (actor, CLUTTER_ACTOR (box));
   clutter_actor_queue_relayout (actor);
 
+  /* we need to explicitly call this, because we're not going through
+   * the default code paths provided by clutter_container_add()
+   */
+  clutter_container_create_child_meta (CLUTTER_CONTAINER (box), actor);
+
   g_signal_emit_by_name (box, "actor-added", actor);
 
   if (first_property == NULL || *first_property == '\0')
