@@ -18,9 +18,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
  */
 /**
  * SECTION:clutter-main
@@ -137,6 +137,9 @@ static guint clutter_main_loop_level         = 0;
 static GSList *main_loops                    = NULL;
 
 guint clutter_debug_flags = 0;  /* global clutter debug flag */
+guint clutter_paint_debug_flags = 0;
+guint clutter_pick_debug_flags = 0;
+
 guint clutter_profile_flags = 0;  /* global clutter profile flag */
 
 const guint clutter_major_version = CLUTTER_MAJOR_VERSION;
@@ -160,16 +163,25 @@ static const GDebugKey clutter_debug_keys[] = {
   { "shader", CLUTTER_DEBUG_SHADER },
   { "multistage", CLUTTER_DEBUG_MULTISTAGE },
   { "animation", CLUTTER_DEBUG_ANIMATION },
-  { "layout", CLUTTER_DEBUG_LAYOUT },
-  { "nop-picking", CLUTTER_DEBUG_NOP_PICKING },
-  { "dump-pick-buffers", CLUTTER_DEBUG_DUMP_PICK_BUFFERS }
+  { "layout", CLUTTER_DEBUG_LAYOUT }
 };
 #endif /* CLUTTER_ENABLE_DEBUG */
 
+static const GDebugKey clutter_pick_debug_keys[] = {
+  { "nop-picking", CLUTTER_DEBUG_NOP_PICKING },
+  { "dump-pick-buffers", CLUTTER_DEBUG_DUMP_PICK_BUFFERS }
+};
+
+static const GDebugKey clutter_paint_debug_keys[] = {
+  { "disable-swap-events", CLUTTER_DEBUG_DISABLE_SWAP_EVENTS },
+  { "disable-clipped-redraws", CLUTTER_DEBUG_DISABLE_CLIPPED_REDRAWS },
+  { "redraws", CLUTTER_DEBUG_REDRAWS }
+};
+
 #ifdef CLUTTER_ENABLE_PROFILE
 static const GDebugKey clutter_profile_keys[] = {
-      {"picking-only", CLUTTER_PROFILE_PICKING_ONLY },
-      {"disable-report", CLUTTER_PROFILE_DISABLE_REPORT }
+  {"picking-only", CLUTTER_PROFILE_PICKING_ONLY },
+  {"disable-report", CLUTTER_PROFILE_DISABLE_REPORT }
 };
 #endif /* CLUTTER_ENABLE_DEBUG */
 
@@ -262,13 +274,11 @@ _clutter_stage_maybe_setup_viewport (ClutterStage *stage)
 void
 _clutter_do_redraw (ClutterStage *stage)
 {
-  ClutterMainContext *ctx;
-  ClutterMasterClock *master_clock;
   static GTimer *timer = NULL;
   static guint timer_n_frames = 0;
+  ClutterMainContext *ctx;
 
-  ctx  = _clutter_context_get_default ();
-  master_clock = _clutter_master_clock_get_default ();
+  ctx = _clutter_context_get_default ();
 
   /* Before we can paint, we have to be sure we have the latest layout */
   _clutter_stage_maybe_relayout (CLUTTER_ACTOR (stage));
@@ -412,7 +422,7 @@ _clutter_id_to_color (guint id, ClutterColor *col)
    * otherwise pick buffers dumped to an image will pretty much just look
    * black.
    */
-  if (G_UNLIKELY (clutter_debug_flags & CLUTTER_DEBUG_DUMP_PICK_BUFFERS))
+  if (G_UNLIKELY (clutter_pick_debug_flags & CLUTTER_DEBUG_DUMP_PICK_BUFFERS))
     {
       col->red   = (col->red << 4)   | (col->red >> 4);
       col->green = (col->green << 4) | (col->green >> 4);
@@ -432,7 +442,7 @@ _clutter_pixel_to_id (guchar pixel[4])
   /* reduce the pixel components to the number of bits actually used of the
    * 8bits.
    */
-  if (G_UNLIKELY (clutter_debug_flags & CLUTTER_DEBUG_DUMP_PICK_BUFFERS))
+  if (G_UNLIKELY (clutter_pick_debug_flags & CLUTTER_DEBUG_DUMP_PICK_BUFFERS))
     {
       guchar tmp;
 
@@ -491,15 +501,15 @@ read_pixels_to_file (char *filename_stem,
   data = g_malloc (4 * width * height);
   cogl_read_pixels (x, y, width, height,
                     COGL_READ_PIXELS_COLOR_BUFFER,
-                    COGL_PIXEL_FORMAT_RGBA_8888,
+                    COGL_PIXEL_FORMAT_RGB_888,
                     data);
   pixbuf = gdk_pixbuf_new_from_data (data,
                                      GDK_COLORSPACE_RGB,
-                                     TRUE, /* has alpha */
+                                     FALSE, /* has alpha */
                                      8, /* bits per sample */
                                      width, /* width */
                                      height, /* height */
-                                     width * 4, /* rowstride */
+                                     width * 3, /* rowstride */
                                      pixbuf_free, /* callback to free data */
                                      NULL); /* callback data */
   if (pixbuf)
@@ -541,7 +551,7 @@ _clutter_do_pick (ClutterStage   *stage,
 		  ClutterPickMode mode)
 {
   ClutterMainContext *context;
-  guchar              pixel[4] = { 0xff, 0xff, 0xff, 0xff };
+  guchar              pixel[3] = { 0xff, 0xff, 0xff };
   CoglColor           stage_pick_id;
   guint32             id;
   GLboolean           dither_was_on;
@@ -571,6 +581,7 @@ _clutter_do_pick (ClutterStage   *stage,
                         "The time spent issuing a read pixels",
                         0 /* no application private data */);
 
+  g_return_val_if_fail (CLUTTER_IS_STAGE (stage), NULL);
 
   if (clutter_debug_flags & CLUTTER_DEBUG_NOP_PICKING)
     return CLUTTER_ACTOR (stage);
@@ -590,7 +601,7 @@ _clutter_do_pick (ClutterStage   *stage,
   /* needed for when a context switch happens */
   _clutter_stage_maybe_setup_viewport (stage);
 
-  if (G_LIKELY (!(clutter_debug_flags & CLUTTER_DEBUG_DUMP_PICK_BUFFERS)))
+  if (G_LIKELY (!(clutter_pick_debug_flags & CLUTTER_DEBUG_DUMP_PICK_BUFFERS)))
     cogl_clip_push_window_rectangle (x, y, 1, 1);
 
   cogl_disable_fog ();
@@ -615,7 +626,7 @@ _clutter_do_pick (ClutterStage   *stage,
   context->pick_mode = CLUTTER_PICK_NONE;
   CLUTTER_TIMER_STOP (_clutter_uprof_context, pick_paint);
 
-  if (G_LIKELY (!(clutter_debug_flags & CLUTTER_DEBUG_DUMP_PICK_BUFFERS)))
+  if (G_LIKELY (!(clutter_pick_debug_flags & CLUTTER_DEBUG_DUMP_PICK_BUFFERS)))
     cogl_clip_pop ();
 
   /* Make sure Cogl flushes any batched geometry to the GPU driver */
@@ -625,11 +636,11 @@ _clutter_do_pick (ClutterStage   *stage,
   CLUTTER_TIMER_START (_clutter_uprof_context, pick_read);
   cogl_read_pixels (x, y, 1, 1,
                     COGL_READ_PIXELS_COLOR_BUFFER,
-                    COGL_PIXEL_FORMAT_RGBA_8888,
+                    COGL_PIXEL_FORMAT_RGB_888,
                     pixel);
   CLUTTER_TIMER_STOP (_clutter_uprof_context, pick_read);
 
-  if (G_UNLIKELY (clutter_debug_flags & CLUTTER_DEBUG_DUMP_PICK_BUFFERS))
+  if (G_UNLIKELY (clutter_pick_debug_flags & CLUTTER_DEBUG_DUMP_PICK_BUFFERS))
     {
       read_pixels_to_file ("pick-buffer", 0, 0,
                            clutter_actor_get_width (CLUTTER_ACTOR (stage)),
@@ -1523,7 +1534,8 @@ clutter_init_real (GError **error)
   /* this will take care of initializing Cogl's state and
    * query the GL machinery for features
    */
-  _clutter_feature_init ();
+  if (!_clutter_feature_init (error))
+    return CLUTTER_INIT_ERROR_BACKEND;
 
 #ifdef CLUTTER_ENABLE_PROFILE
     {
@@ -1646,6 +1658,26 @@ pre_parse_hook (GOptionContext  *context,
     }
 #endif /* CLUTTER_ENABLE_PROFILE */
 
+  env_string = g_getenv ("CLUTTER_PICK");
+  if (env_string != NULL)
+    {
+      clutter_pick_debug_flags =
+        g_parse_debug_string (env_string,
+                              clutter_pick_debug_keys,
+                              G_N_ELEMENTS (clutter_pick_debug_keys));
+      env_string = NULL;
+    }
+
+  env_string = g_getenv ("CLUTTER_PAINT");
+  if (env_string != NULL)
+    {
+      clutter_paint_debug_flags =
+        g_parse_debug_string (env_string,
+                              clutter_paint_debug_keys,
+                              G_N_ELEMENTS (clutter_paint_debug_keys));
+      env_string = NULL;
+    }
+
   env_string = g_getenv ("CLUTTER_SHOW_FPS");
   if (env_string)
     clutter_show_fps = TRUE;
@@ -2445,15 +2477,13 @@ _clutter_process_event_details (ClutterActor        *stage,
 void
 _clutter_process_event (ClutterEvent *event)
 {
-  ClutterMainContext  *context;
-  ClutterBackend      *backend;
-  ClutterActor        *stage;
+  ClutterMainContext *context;
+  ClutterActor *stage;
 
   context = _clutter_context_get_default ();
-  backend = context->backend;
-  stage   = CLUTTER_ACTOR(event->any.stage);
 
-  if (!stage)
+  stage = CLUTTER_ACTOR (event->any.stage);
+  if (stage == NULL)
     return;
 
   CLUTTER_TIMESTAMP (EVENT, "Event received");
@@ -2496,8 +2526,6 @@ clutter_base_init (void)
 
   if (!initialised)
     {
-      GType foo; /* Quiet gcc */
-
       initialised = TRUE;
 
       bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
@@ -2505,9 +2533,6 @@ clutter_base_init (void)
 
       /* initialise GLib type system */
       g_type_init ();
-
-      /* CLUTTER_TYPE_ACTOR */
-      foo = clutter_actor_get_type ();
     }
 }
 
