@@ -87,7 +87,12 @@
 #include "clutter-bezier.h"
 #include "clutter-private.h"
 
-G_DEFINE_TYPE (ClutterPath, clutter_path, G_TYPE_INITIALLY_UNOWNED);
+static void clutter_path_register_transforms (GType type);
+
+G_DEFINE_TYPE_WITH_CODE (ClutterPath,
+                         clutter_path,
+                         G_TYPE_INITIALLY_UNOWNED,
+                         clutter_path_register_transforms (g_define_type_id));
 
 #define CLUTTER_PATH_GET_PRIVATE(obj) \
   (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CLUTTER_TYPE_PATH, \
@@ -210,6 +215,35 @@ clutter_path_init (ClutterPath *self)
   self->priv = CLUTTER_PATH_GET_PRIVATE (self);
 }
 
+static void
+clutter_value_transform_path_string (const GValue *src,
+                                     GValue       *dest)
+{
+  gchar *string = clutter_path_get_description (src->data[0].v_pointer);
+
+  g_value_take_string (dest, string);
+}
+
+static void
+clutter_value_transform_string_path (const GValue *src,
+                                     GValue       *dest)
+{
+  ClutterPath *new_path;
+
+  new_path = clutter_path_new_with_description (g_value_get_string (src));
+  g_value_take_object (dest, new_path);
+}
+
+static void
+clutter_path_register_transforms (GType type)
+{
+  g_value_register_transform_func (type, G_TYPE_STRING,
+                                   clutter_value_transform_path_string);
+
+  g_value_register_transform_func (G_TYPE_STRING, type,
+                                   clutter_value_transform_string_path);
+}
+
 static void
 clutter_path_finalize (GObject *object)
 {
@@ -337,7 +371,7 @@ clutter_path_add_node_helper (ClutterPath         *path,
  * @x: the x coordinate
  * @y: the y coordinate
  *
- * Adds a #CLUTTER_PATH_MOVE_TO type node to the path. This is usually
+ * Adds a %CLUTTER_PATH_MOVE_TO type node to the path. This is usually
  * used as the first node in a path. It can also be used in the middle
  * of the path to cause the actor to jump to the new coordinate.
  *
@@ -380,7 +414,7 @@ clutter_path_add_rel_move_to (ClutterPath *path,
  * @x: the x coordinate
  * @y: the y coordinate
  *
- * Adds a #CLUTTER_PATH_LINE_TO type node to the path. This causes the
+ * Adds a %CLUTTER_PATH_LINE_TO type node to the path. This causes the
  * actor to move to the new coordinates in a straight line.
  *
  * Since: 1.0
@@ -426,7 +460,7 @@ clutter_path_add_rel_line_to (ClutterPath *path,
  * @x_3: the x coordinate of the third control point
  * @y_3: the y coordinate of the third control point
  *
- * Adds a #CLUTTER_PATH_CURVE_TO type node to the path. This causes
+ * Adds a %CLUTTER_PATH_CURVE_TO type node to the path. This causes
  * the actor to follow a bezier from the last node to (@x_3, @y_3) using
  * (@x_1, @y_1) and (@x_2,@y_2) as control points.
  *
@@ -485,8 +519,8 @@ clutter_path_add_rel_curve_to (ClutterPath *path,
  * clutter_path_add_close:
  * @path: a #ClutterPath
  *
- * Adds a #CLUTTER_PATH_CLOSE type node to the path. This creates a
- * straight line from the last node to the last #CLUTTER_PATH_MOVE_TO
+ * Adds a %CLUTTER_PATH_CLOSE type node to the path. This creates a
+ * straight line from the last node to the last %CLUTTER_PATH_MOVE_TO
  * type node.
  *
  * Since: 1.0
