@@ -16,9 +16,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
  */
 
 #ifndef __COGL_CLIP_STACK_H
@@ -35,10 +35,16 @@ struct _CoglClipStackState
   gboolean stencil_used;
 };
 
-void _cogl_clip_stack_state_init (CoglClipStackState *state);
-void _cogl_clip_stack_state_destroy (CoglClipStackState *state);
-void _cogl_clip_stack_state_dirty (CoglClipStackState *state);
+void
+_cogl_clip_stack_state_init (CoglClipStackState *state);
 
-void _cogl_flush_clip_state (CoglClipStackState *clip_state);
+void
+_cogl_clip_stack_state_destroy (CoglClipStackState *state);
+
+void
+_cogl_clip_stack_state_dirty (CoglClipStackState *state);
+
+void
+_cogl_flush_clip_state (CoglClipStackState *clip_state);
 
 #endif /* __COGL_CLIP_STACK_H */
