@@ -16,9 +16,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
  *
  * Authors:
  *   Robert Bragg <robert@linux.intel.com>
@@ -83,7 +83,7 @@ G_BEGIN_DECLS
  * Return value: a new #CoglHandle
  */
 CoglHandle
-cogl_vertex_buffer_new (guint n_vertices);
+cogl_vertex_buffer_new (unsigned int n_vertices);
 
 /**
  * cogl_vertex_buffer_get_n_vertices:
@@ -93,7 +93,7 @@ cogl_vertex_buffer_new (guint n_vertices);
  *
  * Return value: the number of vertices
  */
-guint
+unsigned int
 cogl_vertex_buffer_get_n_vertices (CoglHandle handle);
 
 /**
@@ -301,14 +301,22 @@ cogl_vertex_buffer_draw (CoglHandle       handle,
  * CoglIndicesType:
  * @COGL_INDICES_TYPE_UNSIGNED_BYTE: Your indices are unsigned bytes
  * @COGL_INDICES_TYPE_UNSIGNED_SHORT: Your indices are unsigned shorts
+ * @COGL_INDICES_TYPE_UNSIGNED_INT: Your indices are unsigned ints
  *
  * You should aim to use the smallest data type that gives you enough
  * range, since it reduces the size of your index array and can help
  * reduce the demand on memory bandwidth.
+ *
+ * Note that %COGL_INDICES_TYPE_UNSIGNED_INT is only supported if the
+ * %COGL_FEATURE_UNSIGNED_INT_INDICES feature is available. This
+ * should always be available on OpenGL but on OpenGL ES it will only
+ * be available if the GL_OES_element_index_uint extension is
+ * advertized.
  */
 typedef enum {
   COGL_INDICES_TYPE_UNSIGNED_BYTE,
   COGL_INDICES_TYPE_UNSIGNED_SHORT,
+  COGL_INDICES_TYPE_UNSIGNED_INT,
 } CoglIndicesType;
 
 /**
@@ -385,7 +393,7 @@ cogl_vertex_buffer_draw_elements (CoglHandle       handle,
  * Deprecated: 1.2: Use cogl_handle_ref() instead
  */
 CoglHandle
-cogl_vertex_buffer_ref (CoglHandle handle);
+cogl_vertex_buffer_ref (CoglHandle handle) G_GNUC_DEPRECATED;
 
 /**
  * cogl_vertex_buffer_unref:
@@ -396,7 +404,7 @@ cogl_vertex_buffer_ref (CoglHandle handle);
  * Deprecated: 1.2: Use cogl_handle_unref() instead
  */
 void
-cogl_vertex_buffer_unref (CoglHandle handle);
+cogl_vertex_buffer_unref (CoglHandle handle) G_GNUC_DEPRECATED;
 
 #endif /* COGL_DISABLE_DEPRECATED */
 
@@ -439,7 +447,7 @@ cogl_vertex_buffer_unref (CoglHandle handle);
  * owned by Cogl and should not be modified or unref'd.
  */
 CoglHandle
-cogl_vertex_buffer_indices_get_for_quads (guint n_indices);
+cogl_vertex_buffer_indices_get_for_quads (unsigned int n_indices);
 
 /**
  * cogl_is_vertex_buffer:
