@@ -16,9 +16,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
  */
 
 /* This is included multiple times with different definitions for
@@ -70,3 +70,9 @@ COGL_FEATURE_FUNCTION (void, glDeleteFramebuffers,
 COGL_FEATURE_FUNCTION (void, glGenerateMipmap,
                        (GLenum                target))
 COGL_FEATURE_END ()
+
+COGL_FEATURE_BEGIN (element_index_uint, 255, 255,
+                    "OES\0",
+                    "element_index_uint\0",
+                    COGL_FEATURE_UNSIGNED_INT_INDICES)
+COGL_FEATURE_END ()
