@@ -14,15 +14,19 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 #include "clutter-backend-x11.h"
 #include "clutter-stage-x11.h"
 #include "clutter-x11.h"
@@ -66,6 +70,8 @@ send_wmspec_change_state (ClutterBackendX11 *backend_x11,
 {
   XClientMessageEvent xclient;
 
+  CLUTTER_NOTE (BACKEND, "%s NET_WM state", add ? "adding" : "removing");
+
   memset (&xclient, 0, sizeof (xclient));
 
   xclient.type         = ClientMessage;
@@ -121,7 +127,7 @@ clutter_stage_x11_fix_window_size (ClutterStageX11 *stage_x11,
 
       /* If we are going fullscreen then we don't want any
          restrictions on the window size */
-      if (!stage_x11->fullscreen_on_map)
+      if (!stage_x11->fullscreening)
         {
           if (resize)
             {
@@ -169,17 +175,13 @@ clutter_stage_x11_get_geometry (ClutterStageWindow *stage_window,
   ClutterBackend *backend = clutter_get_default_backend ();
   ClutterBackendX11 *backend_x11;
   ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (stage_window);
-  gboolean is_fullscreen;
 
   g_return_if_fail (CLUTTER_IS_BACKEND_X11 (backend));
   backend_x11 = CLUTTER_BACKEND_X11 (backend);
 
-  is_fullscreen = FALSE;
-  g_object_get (G_OBJECT (stage_x11->wrapper),
-                "fullscreen-set", &is_fullscreen,
-                NULL);
-
-  if (is_fullscreen || stage_x11->fullscreen_on_map)
+  /* If we're fullscreen, return the size of the display. */
+  if ((stage_x11->state & CLUTTER_STAGE_STATE_FULLSCREEN) &&
+      stage_x11->fullscreening)
     {
       geometry->width = DisplayWidth (backend_x11->xdpy, backend_x11->xscreen_num);
       geometry->height = DisplayHeight (backend_x11->xdpy, backend_x11->xscreen_num);
@@ -202,6 +204,22 @@ clutter_stage_x11_resize (ClutterStageWindow *stage_window,
   ClutterStage *stage = stage_x11->wrapper;
   gboolean resize;
 
+  if (stage_x11->is_foreign_xwin)
+    {
+      /* If this is a foreign window we won't get a ConfigureNotify,
+       * so we need to manually set the size and queue a relayout on the
+       * stage here (as is normally done in response to ConfigureNotify).
+       */
+      stage_x11->xwin_width = width;
+      stage_x11->xwin_height = height;
+      clutter_actor_queue_relayout (CLUTTER_ACTOR (stage_x11->wrapper));
+      return;
+    }
+
+  /* If we're going fullscreen, don't mess with the size */
+  if (stage_x11->fullscreening)
+    return;
+
   resize = clutter_stage_get_user_resizable (stage_x11->wrapper);
 
   g_return_if_fail (CLUTTER_IS_BACKEND_X11 (backend));
@@ -219,27 +237,26 @@ clutter_stage_x11_resize (ClutterStageWindow *stage_window,
 
   CLUTTER_NOTE (BACKEND, "New size received: (%d, %d)", width, height);
 
-  if (width != stage_x11->xwin_width ||
-      height != stage_x11->xwin_height)
+  if (stage_x11->xwin != None)
     {
-      stage_x11->xwin_width  = width;
-      stage_x11->xwin_height = height;
+      clutter_stage_x11_fix_window_size (stage_x11, width, height);
 
-      if (stage_x11->xwin != None && !stage_x11->is_foreign_xwin)
+      if (width != stage_x11->xwin_width ||
+          height != stage_x11->xwin_height)
         {
           CLUTTER_NOTE (BACKEND, "%s: XResizeWindow[%x] (%d, %d)",
                         G_STRLOC,
                         (unsigned int) stage_x11->xwin,
-                        stage_x11->xwin_width,
-                        stage_x11->xwin_height);
+                        width,
+                        height);
 
           CLUTTER_SET_PRIVATE_FLAGS (stage_x11->wrapper,
                                      CLUTTER_STAGE_IN_RESIZE);
 
           XResizeWindow (backend_x11->xdpy,
                          stage_x11->xwin,
-                         stage_x11->xwin_width,
-                         stage_x11->xwin_height);
+                         width,
+                         height);
 
           /* If the viewport hasn't previously been initialized then even
            * though we can't guarantee that the server will honour our request
@@ -249,17 +266,14 @@ clutter_stage_x11_resize (ClutterStageWindow *stage_window,
             {
               ClutterPerspective perspective;
               clutter_stage_get_perspective (stage, &perspective);
-              _cogl_setup_viewport (stage_x11->xwin_width,
-                                    stage_x11->xwin_height,
+              _cogl_setup_viewport (width,
+                                    height,
                                     perspective.fovy,
                                     perspective.aspect,
                                     perspective.z_near,
                                     perspective.z_far);
             }
         }
-
-      if (!resize)
-        clutter_stage_x11_fix_window_size (stage_x11, width, height);
     }
 }
 
@@ -270,7 +284,7 @@ set_wm_pid (ClutterStageX11 *stage_x11)
   ClutterBackendX11 *backend_x11 = CLUTTER_BACKEND_X11 (backend);
   long pid;
 
-  if (stage_x11->xwin == None)
+  if (stage_x11->xwin == None || stage_x11->is_foreign_xwin)
     return;
 
   /* this will take care of WM_CLIENT_MACHINE and WM_LOCALE_NAME */
@@ -280,7 +294,7 @@ set_wm_pid (ClutterStageX11 *stage_x11)
                     NULL, 0,
                     NULL, NULL, NULL);
 
-  pid = getpid();
+  pid = getpid ();
   XChangeProperty (backend_x11->xdpy,
                    stage_x11->xwin,
                    backend_x11->atom_NET_WM_PID, XA_CARDINAL, 32,
@@ -297,7 +311,7 @@ set_wm_title (ClutterStageX11 *stage_x11)
   g_return_if_fail (CLUTTER_IS_BACKEND_X11 (backend));
   backend_x11 = CLUTTER_BACKEND_X11 (backend);
 
-  if (stage_x11->xwin == None)
+  if (stage_x11->xwin == None || stage_x11->is_foreign_xwin)
     return;
 
   if (stage_x11->title == NULL)
@@ -393,6 +407,11 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
   if (stage == NULL)
     return;
 
+  if (!!(stage_x11->state & CLUTTER_STAGE_STATE_FULLSCREEN) == is_fullscreen)
+    return;
+
+  CLUTTER_NOTE (BACKEND, "%ssetting fullscreen", is_fullscreen ? "" : "un");
+
   CLUTTER_SET_PRIVATE_FLAGS (stage, CLUTTER_ACTOR_SYNC_MATRICES);
 
   if (is_fullscreen)
@@ -407,17 +426,8 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
       width  = DisplayWidth (backend_x11->xdpy, backend_x11->xscreen_num);
       height = DisplayHeight (backend_x11->xdpy, backend_x11->xscreen_num);
 
-      /* we force the stage to the screen size here, in order to
-       * get the fullscreen stage size right after the call to
-       * clutter_stage_fullscreen(). XXX this might break in case
-       * the stage is not fullscreened, but if that does not happen
-       * we are massively screwed anyway
-       */
-      stage_x11->xwin_width = width;
-      stage_x11->xwin_height = height;
-
-      if (!STAGE_X11_IS_MAPPED (stage_x11))
-        stage_x11->fullscreen_on_map = TRUE;
+      /* Set the fullscreen hint so we can retain the old size of the window. */
+      stage_x11->fullscreening = TRUE;
 
       if (stage_x11->xwin != None)
         {
@@ -426,8 +436,10 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
            * a resize when calling clutter_stage_fullscreen() before showing
            * the stage
            */
-          if (!CLUTTER_ACTOR_IS_MAPPED (stage_x11))
+          if (!/*CLUTTER_ACTOR_IS_MAPPED (stage_x11->wrapper)*/ STAGE_X11_IS_MAPPED (stage_x11))
             {
+              CLUTTER_NOTE (BACKEND, "Fullscreening unmapped stage");
+
               /* FIXME: This wont work if we support more states */
               XChangeProperty (backend_x11->xdpy,
                                stage_x11->xwin,
@@ -437,6 +449,8 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
             }
           else
             {
+              CLUTTER_NOTE (BACKEND, "Fullscreening mapped stage");
+
               /* We need to fix the window size so that it will remove
                  the maximum and minimum window hints. Otherwise
                  metacity will honour the restrictions and not
@@ -451,13 +465,14 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
     }
   else
     {
-      if (!STAGE_X11_IS_MAPPED (stage_x11))
-        stage_x11->fullscreen_on_map = FALSE;
+      stage_x11->fullscreening = FALSE;
 
       if (stage_x11->xwin != None)
         {
-          if (!CLUTTER_ACTOR_IS_MAPPED (stage_x11))
+          if (!/*CLUTTER_ACTOR_IS_MAPPED (stage_x11->wrapper)*/ STAGE_X11_IS_MAPPED (stage_x11))
             {
+              CLUTTER_NOTE (BACKEND, "Un-fullscreening unmapped stage");
+
               /* FIXME: This wont work if we support more states */
               XDeleteProperty (backend_x11->xdpy,
                                stage_x11->xwin, 
@@ -465,6 +480,8 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
             }
           else
             {
+              CLUTTER_NOTE (BACKEND, "Un-fullscreening mapped stage");
+
               send_wmspec_change_state (backend_x11,
                                         stage_x11->xwin,
                                         backend_x11->atom_NET_WM_STATE_FULLSCREEN,
@@ -472,7 +489,9 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
 
               /* Fix the window size to restore the minimum/maximum
                  restriction */
-              clutter_stage_x11_fix_window_size (stage_x11, -1, -1);
+              clutter_stage_x11_fix_window_size (stage_x11,
+                                                 stage_x11->xwin_width,
+                                                 stage_x11->xwin_height);
             }
         }
     }
@@ -508,7 +527,9 @@ clutter_stage_x11_set_user_resizable (ClutterStageWindow *stage_window,
 {
   ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (stage_window);
 
-  clutter_stage_x11_fix_window_size (stage_x11, -1, -1);
+  clutter_stage_x11_fix_window_size (stage_x11,
+                                     stage_x11->xwin_width,
+                                     stage_x11->xwin_height);
 }
 
 static void
@@ -579,14 +600,14 @@ clutter_stage_x11_show (ClutterStageWindow *stage_window,
           CLUTTER_NOTE (BACKEND, "Mapping stage[%lu]",
                         (unsigned long) stage_x11->xwin);
 
-          if (stage_x11->fullscreen_on_map)
-            clutter_stage_x11_set_fullscreen (stage_window, TRUE);
-          else
-            clutter_stage_x11_set_fullscreen (stage_window, FALSE);
-
           set_stage_state (stage_x11, STAGE_X11_WITHDRAWN, 0);
 
           update_wm_hints (stage_x11);
+
+          if (stage_x11->fullscreening)
+            clutter_stage_x11_set_fullscreen (stage_window, TRUE);
+          else
+            clutter_stage_x11_set_fullscreen (stage_window, FALSE);
         }
 
       g_assert (STAGE_X11_IS_MAPPED (stage_x11));
@@ -663,7 +684,7 @@ clutter_stage_x11_init (ClutterStageX11 *stage)
   stage->wm_state = STAGE_X11_WITHDRAWN;
 
   stage->is_foreign_xwin = FALSE;
-  stage->fullscreen_on_map = FALSE;
+  stage->fullscreening = FALSE;
   stage->is_cursor_visible = TRUE;
   stage->viewport_initialized = FALSE;
 
